==> ant-design-vue-3.2.20.jar: META-INF/resources/webjars/ant-design-vue/3.2.20/es/vc-slider/src/Handle.d.ts <==
import type { PropType } from 'vue';
declare const _default: import("vue").DefineComponent<{
    prefixCls: StringConstructor;
    vertical: {
        type: BooleanConstructor;
        default: any;
    };
    offset: NumberConstructor;
    disabled: {
        type: BooleanConstructor;
        default: any;
    };
    min: NumberConstructor;
    max: NumberConstructor;
    value: NumberConstructor;
    tabindex: import("vue-types").VueTypeDef<string | number>;
    reverse: {
        type: BooleanConstructor;
        default: any;
    };
    ariaLabel: StringConstructor;
    ariaLabelledBy: StringConstructor;
    ariaValueTextFormatter: FunctionConstructor;
    onMouseenter: {
        type: PropType<(payload: MouseEvent) => void>;
    };
    onMouseleave: {
        type: PropType<(payload: MouseEvent) => void>;
    };
    onMousedown: {
        type: PropType<(payload: MouseEvent) => void>;
    };
}, () => JSX.Element, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, {}, string, import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<import("vue").ExtractPropTypes<{
    prefixCls: StringConstructor;
    vertical: {
        type: BooleanConstructor;
        default: any;
    };
    offset: NumberConstructor;
    disabled: {
        type: BooleanConstructor;
        default: any;
    };
    min: NumberConstructor;
    max: NumberConstructor;
    value: NumberConstructor;
    tabindex: import("vue-types").VueTypeDef<string | number>;
    reverse: {
        type: BooleanConstructor;
        default: any;
    };
    ariaLabel: StringConstructor;
    ariaLabelledBy: StringConstructor;
    ariaValueTextFormatter: FunctionConstructor;
    onMouseenter: {
        type: PropType<(payload: MouseEvent) => void>;
    };
    onMouseleave: {
        type: PropType<(payload: MouseEvent) => void>;
    };
    onMousedown: {
        type: PropType<(payload: MouseEvent) => void>;
    };
}>>, {
    reverse: boolean;
    vertical: boolean;
    disabled: boolean;
}>;
export default _default;

==> ant-design-vue-4.2.6.jar: META-INF/resources/webjars/ant-design-vue/4.2.6/es/vc-slider/src/Handle.d.ts <==
import type { PropType } from 'vue';
declare const _default: import("vue").DefineComponent<import("vue").ExtractPropTypes<{
    prefixCls: StringConstructor;
    vertical: {
        type: BooleanConstructor;
        default: any;
    };
    offset: NumberConstructor;
    disabled: {
        type: BooleanConstructor;
        default: any;
    };
    min: NumberConstructor;
    max: NumberConstructor;
    value: NumberConstructor;
    tabindex: import("vue-types").VueTypeDef<string | number>;
    reverse: {
        type: BooleanConstructor;
        default: any;
    };
    ariaLabel: StringConstructor;
    ariaLabelledBy: StringConstructor;
    ariaValueTextFormatter: FunctionConstructor;
    onMouseenter: {
        type: PropType<(payload: MouseEvent) => void>;
    };
    onMouseleave: {
        type: PropType<(payload: MouseEvent) => void>;
    };
    onMousedown: {
        type: PropType<(payload: MouseEvent) => void>;
    };
}>, () => import("vue/jsx-runtime").JSX.Element, {}, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, {}, string, import("vue").PublicProps, Readonly<import("vue").ExtractPropTypes<{
    prefixCls: StringConstructor;
    vertical: {
        type: BooleanConstructor;
        default: any;
    };
    offset: NumberConstructor;
    disabled: {
        type: BooleanConstructor;
        default: any;
    };
    min: NumberConstructor;
    max: NumberConstructor;
    value: NumberConstructor;
    tabindex: import("vue-types").VueTypeDef<string | number>;
    reverse: {
        type: BooleanConstructor;
        default: any;
    };
    ariaLabel: StringConstructor;
    ariaLabelledBy: StringConstructor;
    ariaValueTextFormatter: FunctionConstructor;
    onMouseenter: {
        type: PropType<(payload: MouseEvent) => void>;
    };
    onMouseleave: {
        type: PropType<(payload: MouseEvent) => void>;
    };
    onMousedown: {
        type: PropType<(payload: MouseEvent) => void>;
    };
}>> & Readonly<{}>, {
    vertical: boolean;
    reverse: boolean;
    disabled: boolean;
}, {}, {}, {}, string, import("vue").ComponentProvideOptions, true, {}, any>;
export default _default;
